@@ -9,6 +9,41 @@ use crate::types::{DateNative, DateTimeNative, DateTimeUtc, DateUtc, Decimal, Ti
 pub fn bind<'a>(t: Bson, mut q: Query<'a, Sqlite, SqliteArguments<'a>>) -> crate::Result<Query<'a, Sqlite, SqliteArguments<'a>>> {
     match t {
         Bson::String(s) => {
+            if s.starts_with("DateTimeUtc(")  {
+                let data: DateTimeUtc = bson::from_bson(Bson::String(s))?;
+                q = q.bind(data.inner);
+                return Ok(q);
+            }
+            if s.starts_with("DateTimeNative(")  {
+                let data: DateTimeNative = bson::from_bson(Bson::String(s))?;
+                q = q.bind(data.inner.to_string());
+                return Ok(q);
+            }
+            if s.starts_with("DateNative(") {
+                let data: DateNative = bson::from_bson(Bson::String(s))?;
+                q = q.bind(data.inner);
+                return Ok(q);
+            }
+            if s.starts_with("DateUtc(") {
+                let data: DateUtc = bson::from_bson(Bson::String(s))?;
+                q = q.bind(data.inner);
+                return Ok(q);
+            }
+            if s.starts_with("TimeUtc(") {
+                let data: TimeUtc = bson::from_bson(Bson::String(s))?;
+                q = q.bind(data.inner);
+                return Ok(q);
+            }
+            if s.starts_with("TimeNative(") {
+                let data: TimeNative = bson::from_bson(Bson::String(s))?;
+                q = q.bind(data.inner);
+                return Ok(q);
+            }
+            if s.starts_with("Decimal(") {
+                let data: Decimal = bson::from_bson(Bson::String(s))?;
+                q = q.bind(data.inner.to_string());
+                return Ok(q);
+            }
             q = q.bind(Some(s));
         }
         Bson::Null => {
@@ -42,30 +77,6 @@ pub fn bind<'a>(t: Bson, mut q: Query<'a, Sqlite, SqliteArguments<'a>>) -> crate
                         crate::types::BINARY_SUBTYPE_JSON => {
                             q = q.bind(d.bytes);
                         }
-                        crate::types::BINARY_SUBTYPE_DECIMAL => {
-                            let data: Decimal = bson::from_slice(&d.bytes)?;
-                            q = q.bind(data.inner.to_string());
-                        }
-                        crate::types::BINARY_SUBTYPE_DATETIME_UTC => {
-                            let data: DateTimeUtc = bson::from_slice(&d.bytes)?;
-                            q = q.bind(data.inner);
-                        }
-                        crate::types::BINARY_SUBTYPE_DATE_LOCAL => {
-                            let data: DateNative = bson::from_slice(&d.bytes)?;
-                            q = q.bind(data.inner);
-                        }
-                        crate::types::BINARY_SUBTYPE_DATE_UTC => {
-                            let data: DateUtc = bson::from_slice(&d.bytes)?;
-                            q = q.bind(data.inner);
-                        }
-                        crate::types::BINARY_SUBTYPE_TIME_UTC => {
-                            let data: TimeUtc = bson::from_slice(&d.bytes)?;
-                            q = q.bind(data.inner);
-                        }
-                        crate::types::BINARY_SUBTYPE_TIME_LOCAL => {
-                            let data: TimeNative = bson::from_slice(&d.bytes)?;
-                            q = q.bind(data.inner);
-                        }
                         _ => {
                             return Err(Error::from("un supported bind type!"));
                         }
