@@ -1,5 +1,6 @@
 //! Types and traits for decoding values from the database.
 use bson::Bson;
+use log::info;
 use serde::de::DeserializeOwned;
 
 use crate::{Error};
@@ -10,16 +11,26 @@ use crate::types::Format;
 /// support decode types:
 /// Bson,BigDecimal, i8..i64,u8..u64,bson::Int64(),bool,String
 /// or object used bson macro object
-pub fn decode<T: ?Sized>(mut datas: Vec<Bson>) -> Result<T, crate::Error>
+pub fn decode<T: ?Sized>(mut datas: bson::Array) -> Result<T, crate::Error>
     where
         T: DeserializeOwned,
 {
-    let mut js = Bson::Null;
     let mut type_name = std::any::type_name::<T>();
     //debug_mode feature print json_decode json data
+    let bs = Bson::Array(datas);
     #[cfg(feature = "debug_mode")]
-    println!("[rbatis] [debug_mode] {} => {}", type_name, datas.do_format());
-
+        {
+            println!("[rbatis] [debug_mode] [bson]   {} => {}", type_name, bs);
+            #[cfg(feature = "format_bson")]
+            println!("[rbatis] [debug_mode] [format] {} => {}", type_name, bs.as_array().unwrap().do_format());
+        }
+    let mut datas = vec![];
+    match bs {
+        Bson::Array(arr) => {
+            datas = arr;
+        }
+        _ => {}
+    }
     // Hit a non-array object
     match type_name {
         //decode single type option
@@ -40,24 +51,22 @@ pub fn decode<T: ?Sized>(mut datas: Vec<Bson>) -> Result<T, crate::Error>
         "bigdecimal::BigDecimal" |
         "bool" |
         "alloc::string::String" => {
-            return Ok(decode_one(type_name, &mut datas)?);
-        }
-        _ => {
-
+            return Ok(try_decode_doc(type_name, &mut datas)?);
         }
+        _ => {}
     }
     // try speculate type
     let is_array: Result<T, bson::de::Error> = bson::from_bson(bson::Bson::Array(vec![]));
     if is_array.is_ok() {
         //decode array
-        js = Bson::Array(datas);
-        return Ok(bson::from_bson(js)?);
+        Ok(bson::from_bson(Bson::Array(datas))?)
     } else {
-        Ok(decode_one(type_name, &mut datas)?)
+        Ok(try_decode_doc(type_name, &mut datas)?)
     }
 }
 
-pub fn decode_one<T>(type_name: &str, datas: &mut Vec<Bson>) -> Result<T, crate::Error>
+//decode doc or one type
+pub fn try_decode_doc<T>(type_name: &str, datas: &mut Vec<Bson>) -> Result<T, crate::Error>
     where
         T: DeserializeOwned, {
     //decode struct
