@@ -1,6 +1,6 @@
 use bson::{bson, Bson, to_bson};
 use bson::spec::BinarySubtype;
-use chrono::Local;
+use chrono::{Utc};
 use sqlx_core::column::Column;
 use sqlx_core::decode::Decode;
 use sqlx_core::error::BoxDynError;
@@ -51,10 +51,9 @@ impl<'c> JsonCodec for SqliteValueRef<'c> {
                 return Ok(to_bson(&r).unwrap_or_default());
             }
             "DATETIME" => {
-                let r: Option<chrono::DateTime<Local>> = Decode::<'_, Sqlite>::decode(self)?;
-                if let Some(r) = r {
-                    let dt = bson::DateTime::from_chrono(r);
-                    return Ok(Bson::DateTime(dt));
+                let r: Option<chrono::NaiveDateTime> = Decode::<'_, Sqlite>::decode(self)?;
+                if let Some(dt) = r {
+                    return Ok(Bson::String(dt.format("%Y-%m-%dT%H:%M:%S").to_string()));
                 }
                 return Ok(Bson::Null);
             }
