@@ -3,20 +3,20 @@ use std::str::FromStr;
 use std::time::SystemTime;
 use bson::{Bson, DateTime};
 use bson::spec::BinarySubtype;
-use chrono::{Local, Utc};
+use chrono::{Local, NaiveDateTime, Utc};
 use serde::{Deserializer, Serializer};
 use serde::de::Error;
 
 /// Rbatis DateTime
 #[derive(Clone, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
 pub struct DateTimeNative {
-    pub inner: chrono::DateTime<Local>,
+    pub inner: chrono::NaiveDateTime,
 }
 
 impl From<bson::DateTime> for DateTimeNative {
     fn from(arg: DateTime) -> Self {
         Self {
-            inner: arg.to_chrono().with_timezone(&chrono::Local),
+            inner: arg.to_chrono().with_timezone(&chrono::Local).naive_local(),
         }
     }
 }
@@ -24,7 +24,7 @@ impl From<bson::DateTime> for DateTimeNative {
 impl From<chrono::DateTime<Local>> for DateTimeNative {
     fn from(arg: chrono::DateTime<Local>) -> Self {
         DateTimeNative {
-            inner: arg
+            inner: arg.naive_local()
         }
     }
 }
@@ -32,35 +32,46 @@ impl From<chrono::DateTime<Local>> for DateTimeNative {
 impl From<&chrono::DateTime<Local>> for DateTimeNative {
     fn from(arg: &chrono::DateTime<Local>) -> Self {
         DateTimeNative {
-            inner: arg.clone()
+            inner: arg.clone().naive_local()
         }
     }
 }
 
 impl serde::Serialize for DateTimeNative {
+    #[inline]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where S: Serializer {
-        return bson::DateTime::from_chrono(self.inner.clone()).serialize(serializer);
+        struct FormatWrapped<'a, D: 'a> {
+            inner: &'a D,
+        }
+        impl<'a, D: std::fmt::Debug> std::fmt::Display for FormatWrapped<'a, D> {
+            fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+                self.inner.fmt(f)
+            }
+        }
+        return serializer.serialize_str(&format!("DateTimeNative({})", FormatWrapped { inner: &self }.to_string()));
     }
 }
 
 impl<'de> serde::Deserialize<'de> for DateTimeNative {
+    #[inline]
     fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where D: Deserializer<'de> {
         match Bson::deserialize(deserializer)? {
             Bson::DateTime(date) => {
                 return Ok(Self {
-                    inner: date.to_chrono().with_timezone(&chrono::Local),
+                    inner: date.to_chrono().with_timezone(&chrono::Local).naive_local(),
                 });
             }
             Bson::String(s) => {
-                return Ok(Self {
-                    inner: chrono::DateTime::<chrono::Local>::from_str(&s).or_else(|e| Err(D::Error::custom(e.to_string())))?,
-                });
-            }
-            Bson::Binary(data) => {
-                let s = String::from_utf8(data.bytes).unwrap_or_default();
-                return Ok(Self {
-                    inner: chrono::DateTime::<chrono::Local>::from_str(&s).or_else(|ex| Err(D::Error::custom(ex.to_string())))?,
-                });
+                if s.starts_with("DateTimeNative(") && s.ends_with(")") {
+                    let inner_data = &s["DateTimeNative(".len()..(s.len() - 1)];
+                    return Ok(Self {
+                        inner: chrono::NaiveDateTime::from_str(inner_data).or_else(|e| Err(D::Error::custom(e.to_string())))?,
+                    });
+                } else {
+                    return Ok(Self {
+                        inner: chrono::NaiveDateTime::from_str(&s).or_else(|e| Err(D::Error::custom(e.to_string())))?,
+                    });
+                }
             }
             _ => {
                 Err(D::Error::custom("deserialize un supported bson type!"))
@@ -71,18 +82,34 @@ impl<'de> serde::Deserialize<'de> for DateTimeNative {
 
 impl std::fmt::Display for DateTimeNative {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        self.inner.fmt(f)
+        struct FormatWrapped<'a, D: 'a> {
+            inner: &'a D,
+        }
+        impl<'a, D: std::fmt::Debug> std::fmt::Display for FormatWrapped<'a, D> {
+            fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+                self.inner.fmt(f)
+            }
+        }
+        FormatWrapped { inner: &self.inner }.fmt(f)
     }
 }
 
 impl std::fmt::Debug for DateTimeNative {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        self.inner.fmt(f)
+        struct FormatWrapped<'a, D: 'a> {
+            inner: &'a D,
+        }
+        impl<'a, D: std::fmt::Debug> std::fmt::Debug for FormatWrapped<'a, D> {
+            fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+                self.inner.fmt(f)
+            }
+        }
+        FormatWrapped { inner: &self.inner }.fmt(f)
     }
 }
 
 impl Deref for DateTimeNative {
-    type Target = chrono::DateTime<Local>;
+    type Target = chrono::NaiveDateTime;
 
     fn deref(&self) -> &Self::Target {
         &self.inner
@@ -101,13 +128,13 @@ impl DateTimeNative {
     pub fn now() -> DateTimeNative {
         let dt = bson::DateTime::now();
         Self {
-            inner: dt.to_chrono().with_timezone(&Local)
+            inner: dt.to_chrono().naive_local()
         }
     }
 
     /// create from str
     pub fn from_str(arg: &str) -> Result<Self, crate::error::Error> {
-        let inner = chrono::DateTime::<Local>::from_str(arg)?;
+        let inner = chrono::NaiveDateTime::from_str(arg)?;
         Ok(Self {
             inner: inner
         })
@@ -116,7 +143,7 @@ impl DateTimeNative {
 
 #[cfg(test)]
 mod test {
-    use crate::types::{DateTimeNative, DateTimeUtc};
+    use crate::types::{DateTimeNative};
 
     #[test]
     fn test_native() {
@@ -129,25 +156,27 @@ mod test {
 
     #[test]
     fn test_utc() {
-        let dt = DateTimeUtc::now();
+        let dt = DateTimeNative::now();
+        println!("{}",dt);
         let s = bson::to_bson(&dt).unwrap();
-        let dt_new: DateTimeUtc = bson::from_bson(s).unwrap();
+        let dt_new: DateTimeNative = bson::from_bson(s).unwrap();
         println!("{},{}", dt.timestamp_millis(), dt_new.timestamp_millis());
         assert_eq!(dt, dt_new);
     }
 
     #[test]
     fn test_decode() {
-        let s = bson::Bson::String("2021-10-31T05:09:16.167 UTC".to_string());
-        let dt_new: DateTimeUtc = bson::from_bson(s).unwrap();
-        println!("{},{}", 1635656956167i64, dt_new.timestamp_millis());
-        assert_eq!(1635656956167i64, dt_new.timestamp_millis());
+        let s = bson::Bson::String("2015-09-18T23:56:04".to_string());
+        let dt_new: DateTimeNative = bson::from_bson(s).unwrap();
+        println!("{},{}", 1442620564000i64, dt_new.timestamp_millis());
+        assert_eq!(1442620564000i64, dt_new.timestamp_millis());
     }
 
     #[test]
     fn test_ser_de() {
         let b = DateTimeNative::now();
         let bsons = bson::to_bson(&b).unwrap();
+        println!("{}",bsons);
         let b_de: DateTimeNative = bson::from_bson(bsons).unwrap();
         assert_eq!(b, b_de);
     }
